"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Delay = void 0;
const AbortError_1 = require("./AbortError");
class Delay {
    /**
     * Promise set timeout wrapper.
     * @param timeout timeout in ms
     * @param signal abort signal
     */
    static wait(timeout, signal) {
        return new Promise((resolve, reject) => {
            // intervalId has to be defined here,
            // as abortCallback can execute before setTimeout is executed
            // eslint-disable-next-line prefer-const
            let intervalId;
            function abortCallback() {
                clearTimeout(intervalId);
                reject(new AbortError_1.AbortError());
            }
            if (signal === null || signal === void 0 ? void 0 : signal.aborted) {
                return abortCallback();
            }
            intervalId = setTimeout(() => {
                signal === null || signal === void 0 ? void 0 : signal.removeEventListener('abort', abortCallback);
                resolve();
            }, timeout);
            signal === null || signal === void 0 ? void 0 : signal.addEventListener('abort', abortCallback);
        });
    }
}
exports.Delay = Delay;
//# sourceMappingURL=DelayHelper.js.map