import { BacktraceAttachment } from '../attachment';
import { BacktraceStackFrame } from '../data/BacktraceStackTrace';
import { BacktraceReportStackTraceInfo } from './BacktraceReportStackTraceInfo';
export declare class BacktraceReport {
    readonly data: Error | string;
    readonly attributes: Record<string, unknown>;
    readonly attachments: BacktraceAttachment[];
    /**
     * Report classifiers
     */
    readonly classifiers: string[];
    /**
     * Report annotations
     */
    readonly annotations: Record<string, object>;
    /**
     * Report stack trace
     */
    readonly stackTrace: Record<string, BacktraceReportStackTraceInfo | BacktraceStackFrame[]>;
    /**
     * Report message
     */
    readonly message: string;
    /**
     * Report inner errors
     */
    readonly innerReport: unknown[];
    /**
     * Report timestamp in ms
     */
    readonly timestamp: number;
    /**
     * Sets how many top frames should be skipped.
     */
    skipFrames: number;
    /**
     * Add additional stack trace to the report.
     * If the thread name already exists it will be overwritten
     * @param name thread name
     * @param stack stack trace
     * @param message error message
     */
    addStackTrace(name: string, stack: string, message?: string): this;
    addStackTrace(name: string, stackFrames: BacktraceStackFrame[]): this;
    constructor(data: Error | string, attributes?: Record<string, unknown>, attachments?: BacktraceAttachment[], options?: {
        skipFrames?: number;
        classifiers?: string[];
        timestamp?: number;
    });
    private generateErrorMessage;
}
