"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConsoleEventSubscriber = void 0;
const textFormatter_1 = require("../../../common/textFormatter");
const BreadcrumbLogLevel_1 = require("../model/BreadcrumbLogLevel");
const BreadcrumbType_1 = require("../model/BreadcrumbType");
class ConsoleEventSubscriber {
    constructor() {
        /**
         * All overriden console events
         */
        this._events = {};
    }
    start(backtraceBreadcrumbs) {
        if ((backtraceBreadcrumbs.breadcrumbsType & BreadcrumbType_1.BreadcrumbType.Log) !== BreadcrumbType_1.BreadcrumbType.Log) {
            return;
        }
        this._formatter = (0, textFormatter_1.textFormatter)();
        this.bindToConsoleMethod('log', BreadcrumbLogLevel_1.BreadcrumbLogLevel.Info, backtraceBreadcrumbs);
        this.bindToConsoleMethod('warn', BreadcrumbLogLevel_1.BreadcrumbLogLevel.Warning, backtraceBreadcrumbs);
        this.bindToConsoleMethod('error', BreadcrumbLogLevel_1.BreadcrumbLogLevel.Error, backtraceBreadcrumbs);
        this.bindToConsoleMethod('debug', BreadcrumbLogLevel_1.BreadcrumbLogLevel.Debug, backtraceBreadcrumbs);
        this.bindToConsoleMethod('trace', BreadcrumbLogLevel_1.BreadcrumbLogLevel.Verbose, backtraceBreadcrumbs);
    }
    dispose() {
        for (const key in this._events) {
            const consoleMethod = this._events[key];
            console[key] = consoleMethod;
        }
    }
    bindToConsoleMethod(name, level, backtraceBreadcrumbs) {
        const originalMethod = console[name];
        console[name] = (...args) => {
            originalMethod(...args);
            const message = this._formatter(...args);
            backtraceBreadcrumbs.addBreadcrumb(message, level, BreadcrumbType_1.BreadcrumbType.Log);
        };
        this._events[name] = originalMethod;
    }
}
exports.ConsoleEventSubscriber = ConsoleEventSubscriber;
//# sourceMappingURL=ConsoleEventSubscriber.js.map