"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BacktraceDatabaseFileStorageProvider = void 0;
const jsonEscaper_1 = require("../../common/jsonEscaper");
const BacktraceDatabaseFileRecord_1 = require("./BacktraceDatabaseFileRecord");
class BacktraceDatabaseFileStorageProvider {
    constructor(_fileSystem, _path) {
        this._fileSystem = _fileSystem;
        this._path = _path;
        this._enabled = true;
        this.RECORD_SUFFIX = '-record.json';
    }
    /**
     * Create a provider if provided options are valid
     * @param options database configuration
     * @returns database file storage provider
     */
    static createIfValid(fileSystem, options) {
        if (!options) {
            return undefined;
        }
        if (!options.enable) {
            return undefined;
        }
        if (options.enable && !options.path) {
            throw new Error('Missing mandatory path to the database. Please define the database.path option in the configuration.');
        }
        return new BacktraceDatabaseFileStorageProvider(fileSystem, options.path);
    }
    start() {
        // make sure by mistake we don't create anything or start any operation
        if (this._enabled === false) {
            return false;
        }
        return true;
    }
    delete(record) {
        const recordPath = this.getRecordPath(record.id);
        return this.unlinkRecord(recordPath);
    }
    add(record) {
        const recordPath = this.getRecordPath(record.id);
        try {
            this._fileSystem.writeFileSync(recordPath, JSON.stringify(BacktraceDatabaseFileRecord_1.BacktraceDatabaseFileRecord.fromRecord(record), (0, jsonEscaper_1.jsonEscaper)()));
            return true;
        }
        catch (_a) {
            return false;
        }
    }
    get() {
        return __awaiter(this, void 0, void 0, function* () {
            const databaseFiles = yield this._fileSystem.readDir(this._path);
            const recordNames = databaseFiles
                .filter((file) => file.endsWith(this.RECORD_SUFFIX))
                .map((f) => this._path + '/' + f);
            const records = [];
            for (const recordName of recordNames) {
                try {
                    const recordJson = yield this._fileSystem.readFile(recordName);
                    const record = BacktraceDatabaseFileRecord_1.BacktraceDatabaseFileRecord.fromJson(recordJson, this._fileSystem);
                    if (!record) {
                        yield this._fileSystem.unlink(recordName);
                        continue;
                    }
                    records.push(record);
                }
                catch (_a) {
                    yield this._fileSystem.unlink(recordName);
                }
            }
            return records;
        });
    }
    unlinkRecord(recordPath) {
        if (!this._fileSystem.existsSync(recordPath)) {
            return false;
        }
        try {
            this._fileSystem.unlinkSync(recordPath);
            return true;
        }
        catch (_a) {
            return false;
        }
    }
    getRecordPath(id) {
        return this._path + '/' + `${id}${this.RECORD_SUFFIX}`;
    }
}
exports.BacktraceDatabaseFileStorageProvider = BacktraceDatabaseFileStorageProvider;
//# sourceMappingURL=BacktraceDatabaseFileStorageProvider.js.map